#
# spec file for package python-gnocchiclient
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global sname gnocchiclient
Name:           python-gnocchiclient
Version:        2.5.0
Release:        2.10
Summary:        Python API and CLI for OpenStack Gnocchi
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/openstack/%{name}
Source0:        https://pypi.io/packages/source/g/%{sname}/%{sname}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-devel
BuildRequires:  python-futurist >= 0.11.0
BuildRequires:  python-oslotest >= 1.10.0
BuildRequires:  python-pbr >= 1.6
BuildRequires:  python-pyparsing >= 2.0.1
BuildRequires:  python-python-subunit >= 0.0.18
BuildRequires:  python-requests >= 2.10.0
BuildRequires:  python-setuptools >= 16.0
BuildRequires:  python-testrepository >= 0.0.18
BuildRequires:  python-testtools >= 1.4.0
Requires:       python-cliff >= 1.15.0
Requires:       python-futurist >= 0.11.0
Requires:       python-keystoneauth1 >= 2.10.0
Requires:       python-osc-lib >= 0.4.0
Requires:       python-oslo.serialization >= 1.10.0
Requires:       python-oslo.utils >= 3.16.0
Requires:       python-pbr >= 1.6
Requires:       python-pyparsing >= 2.0.1
Requires:       python-six >= 1.9.0
BuildArch:      noarch

%description
This is a client library for Gnocchi built on the Gnocchi API. It
provides a Python API (the gnocchiclient module) and a command-line tool.

%package doc
Summary:        Documentation for OpenStack Gnocchi API Client
Group:          Documentation
BuildRequires:  python-Sphinx
BuildRequires:  python-oslosphinx >= 2.5.0

%description      doc
This is a client library for Gnocchi built on the Gnocchi API. It
provides a Python API (the gnocchiclient module) and a command-line tool
(gnocchi).

This package contains auto-generated documentation.

%prep
%setup -q -n %{sname}-%{version}

%build
%py2_build

%install
%py2_install

%{__python2} setup.py build_sphinx
# Fix hidden-file-or-dir warnings
rm -rf html/.doctrees html/.buildinfo

%check
# FIXME: only run unittests for now. Functional tests need gnocchi
export OS_TEST_PATH=./gnocchiclient/tests/unit
PYTHONPATH=. %{__python2} setup.py testr

%files
%doc README.rst
%license LICENSE
%{_bindir}/gnocchi
%{python2_sitelib}/gnocchiclient
%{python2_sitelib}/*.egg-info

%files doc
%doc doc/build/html
%license LICENSE

%changelog
* Mon Sep  5 2016 tbechtold@suse.com
  update to version 2.5.0
  * Use osc-lib instead of openstackclient
  * Remove redundant parentheses
  * Fix bad entry points in setup.cfg
  * [Trivial] Remove executable privilege of doc/source/conf.py
  * noauth: fix endpoint envvar
  * doc: use pbr to auto-generate doc
  * Translate resource_id to UUID5 format.
  * Add mailmap entry for sileht
  * exceptions: use lower case everywhere
  * Use pifpaf instead of overtest to run tests
  * Fix gate failures
  * Remove testscenarios dependency
  * doc: some improvements
  * Add granularity argument to measures aggregation
  * Use overtest to run Gnocchi
  * Raise the correct exception on archive policy rule not found
  * Bump hacking to 0.11.0
  * Switch from deprecated tempest-lib to tempest
  * Quote query string when POST is used
  * utils: allow to encode params with list/tuple
  * Remove refernces to queues in the osc client
  * Use extras in setup.cfg for deps
  * fix typos in comment & help string
  * Raise an error when metric name doesn't exists
  * Make the wheel universal
  * Allow to start Gnocchi command with OSC
  * Prepare compatibility with OSC
  * fix test debug
  * Remove i18n support
  * Supported resources list cli support
  * Ensure description exists for HTTP error.
  * Fix a spell typos
  * exceptions: use url from Reponse object
  * Show original_resource_id in resource list cmd
  * Support newer version of MySQL
  * Allow create resource type
  * utils: allow UUID to not have any dash
  * shell: document query parameters
  * Allow to list resource-types
  * utils: switch format function to functional
  * Remove discover test-dependency
  * Allow to show a resource type
  * show and add unit for metric list and create
  * doc: fix typo in shell
  * Use tox to install Gnocchi
  * Trival: Remove unused logging import
  * utils: include 0 values
  * cli: use type kwarg from argparse to parse queries
  * Add granularity argument to measures show
  * resource: show all attributes when requesting detailed history
  * Make utils.dict_to_querystring result predictible
  * [resource] fix custom formatting of metrics
  * shell: disallow abbrev in argparse
  * Clean flake8 ignore
  * search: Ensure we didn't ignore extra chars
  * Fix gnocchi new install deps and func test
  * supplement the type of marker explaination
  * benchmark: allow to wait for all measures to be processed
  * Corrected docstring for create metric
  * Fix delete metric on resource create/update
  * resource: move --delete-metric to update only
  * Add doc building for gnocchi.xyz
  * exceptions: fix typo in class name
  * Delete openstack/common from the exclude list of flake8 in tox
  * Allow to delete a resource type
  * benchmark: minimize client computed time
  * metric: add support for groupby in aggregation
  * Fix docstring in from_response
  * Use overtest to run MySQL
  * remove MANIFEST.in
  * minimise report
  * fix custom formatting of archive policy
  * Add batching to client
  * add support for update archive policy
  * Update the home-page with developer documentation
  * fix benchmark entry points
  * tests: do not use "low" as archive policy name
  * Add support for Python 3.5
  * The search query is mandatory
  * one type error in resource.py
  * tests: Fix option names
  * shell: remove "resource list-types"
- Update _service and switch to upstream spec template
* Fri Mar 18 2016 dmueller@suse.com
- downgrade python-gnocchi to recommends
* Wed Mar  2 2016 dmueller@suse.com
- update to 2.1.0:
  * Allow to set resource type for aggregation
  * Examples in doc should be workable
  * Handle rename from dbsync to upgrade
  * Fixed history parameter having no effect on search
* Thu Jan 21 2016 aplanas@suse.com
- Initial package
